summaryrefslogtreecommitdiffstats
path: root/korn/boxcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/boxcontainer.h')
-rw-r--r--korn/boxcontainer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/korn/boxcontainer.h b/korn/boxcontainer.h
index 33e1c63d..3f5a54e0 100644
--- a/korn/boxcontainer.h
+++ b/korn/boxcontainer.h
@@ -38,10 +38,10 @@ public:
/**
* Constructor: everything is passed to TQObject.
*
* @param tqparent The tqparent of this object
* @param name The name of this object
*/
- BoxContainer( TQObject *tqparent = 0, const char * name = 0 );
+ BoxContainer( TQObject *parent = 0, const char * name = 0 );
/**
* Destructor
*/
@@ -38,10 +38,10 @@ public:
* Constructor: everything is passed to TQObject.
*
- * @param tqparent The tqparent of this object
+ * @param parent The parent of this object
* @param name The name of this object
*/